@@ -1,18 +1,20 @@
-use chrono::Utc;
+use anyhow::Result;
+use time::{format_description::well_known::Rfc3339, OffsetDateTime};
 
-pub fn main() {
+pub fn main() -> Result<()> {
     println!("cargo:rerun-if-changed=build.rs");
     // These are here so some doc tests work
-    let now = Utc::now();
+    let now = OffsetDateTime::now_utc();
     println!(
         "cargo:rustc-env=VERGEN_BUILD_TIMESTAMP={}",
-        now.to_rfc3339()
+        now.format(&Rfc3339)?
     );
     println!("cargo:rustc-env=VERGEN_GIT_SEMVER=v3.2.0-86-g95fc0f5");
     nightly_lints();
     beta_lints();
     stable_lints();
     msrv_lints();
+    Ok(())
 }
 
 #[rustversion::nightly]
@@ -39,7 +41,7 @@ fn stable_lints() {
 #[rustversion::not(stable)]
 fn stable_lints() {}
 
-#[rustversion::before(1.57)]
+#[rustversion::before(1.58)]
 fn msrv_lints() {}
 
 #[rustversion::since(1.58)]
