@@ -18,10 +18,13 @@ use {
         error::Error,
         feature::{self, add_entry, TimestampKind},
     },
-    chrono::{DateTime, FixedOffset, Local, TimeZone, Utc},
     getset::{CopyGetters, Getters, MutGetters},
     git2::{BranchType, DescribeFormatOptions, DescribeOptions, Repository},
     std::{env, path::PathBuf},
+    time::{
+        format_description::{self, well_known::Rfc3339},
+        OffsetDateTime, UtcOffset,
+    },
 };
 
 /// The semver kind to output
@@ -38,10 +41,12 @@ pub enum SemverKind {
 #[cfg(feature = "git")]
 #[derive(Clone, Copy, Debug, Eq, PartialEq)]
 pub enum ShaKind {
-    /// Output the normal 40 digit SHA
+    /// Output the normal 40 digit SHA: `VERGEN_GIT_SHA`
     Normal,
-    /// Output the short 7 digit SHA
+    /// Output the short 7 digit SHA: `VERGEN_GIT_SHA_SHORT`
     Short,
+    /// Output both SHA variants: `VERGEN_GIT_SHA` and `VERGEN_GIT_SHA_SHORT`
+    Both,
 }
 
 /// Configuration for the `VERGEN_GIT_*` instructions
@@ -222,20 +227,23 @@ where
                 let commit = ref_head.peel_to_commit()?;
 
                 if *git_config.commit_timestamp() {
-                    let offset = if commit.time().sign() == '-' {
-                        FixedOffset::west(commit.time().offset_minutes() * 60)
-                            .timestamp(commit.time().seconds(), 0)
-                    } else {
-                        FixedOffset::east(commit.time().offset_minutes() * 60)
-                            .timestamp(commit.time().seconds(), 0)
-                    };
+                    let commit_time = OffsetDateTime::from_unix_timestamp(commit.time().seconds())?;
 
                     match git_config.commit_timestamp_timezone() {
                         crate::TimeZone::Utc => {
-                            add_config_entries(config, git_config, &offset.with_timezone(&Utc));
+                            add_config_entries(
+                                config,
+                                git_config,
+                                &commit_time.to_offset(UtcOffset::UTC),
+                            )?;
                         }
+                        #[cfg(feature = "local_offset")]
                         crate::TimeZone::Local => {
-                            add_config_entries(config, git_config, &offset.with_timezone(&Local));
+                            add_config_entries(
+                                config,
+                                git_config,
+                                &commit_time.to_offset(UtcOffset::current_local_offset()?),
+                            )?;
                         }
                     }
                 }
@@ -257,6 +265,20 @@ where
                                 obj.short_id()?.as_str().map(str::to_string),
                             );
                         }
+                        crate::ShaKind::Both => {
+                            add_entry(
+                                config.cfg_map_mut(),
+                                VergenKey::Sha,
+                                Some(commit.id().to_string()),
+                            );
+
+                            let obj = repo.revparse_single("HEAD")?;
+                            add_entry(
+                                config.cfg_map_mut(),
+                                VergenKey::ShortSha,
+                                obj.short_id()?.as_str().map(str::to_string),
+                            );
+                        }
                     }
                 }
             }
@@ -292,64 +314,54 @@ where
 }
 
 #[cfg(feature = "git")]
-fn add_config_entries<T>(config: &mut Config, git_config: &Git, now: &DateTime<T>)
-where
-    T: TimeZone,
-    T::Offset: std::fmt::Display,
-{
+fn add_config_entries(config: &mut Config, git_config: &Git, now: &OffsetDateTime) -> Result<()> {
     match git_config.commit_timestamp_kind() {
-        TimestampKind::DateOnly => add_date_entry(config, now),
-        TimestampKind::TimeOnly => add_time_entry(config, now),
+        TimestampKind::DateOnly => add_date_entry(config, now)?,
+        TimestampKind::TimeOnly => add_time_entry(config, now)?,
         TimestampKind::DateAndTime => {
-            add_date_entry(config, now);
-            add_time_entry(config, now);
+            add_date_entry(config, now)?;
+            add_time_entry(config, now)?;
         }
-        TimestampKind::Timestamp => add_timestamp_entry(config, now),
+        TimestampKind::Timestamp => add_timestamp_entry(config, now)?,
         TimestampKind::All => {
-            add_date_entry(config, now);
-            add_time_entry(config, now);
-            add_timestamp_entry(config, now);
+            add_date_entry(config, now)?;
+            add_time_entry(config, now)?;
+            add_timestamp_entry(config, now)?;
         }
     }
+    Ok(())
 }
 
 #[cfg(feature = "git")]
-fn add_date_entry<T>(config: &mut Config, now: &DateTime<T>)
-where
-    T: TimeZone,
-    T::Offset: std::fmt::Display,
-{
+fn add_date_entry(config: &mut Config, now: &OffsetDateTime) -> Result<()> {
+    let format = format_description::parse("[year]-[month]-[day]")?;
     add_entry(
         config.cfg_map_mut(),
         VergenKey::CommitDate,
-        Some(now.format("%Y-%m-%d").to_string()),
+        Some(now.format(&format)?),
     );
+    Ok(())
 }
 
 #[cfg(feature = "git")]
-fn add_time_entry<T>(config: &mut Config, now: &DateTime<T>)
-where
-    T: TimeZone,
-    T::Offset: std::fmt::Display,
-{
+fn add_time_entry(config: &mut Config, now: &OffsetDateTime) -> Result<()> {
+    let format = format_description::parse("[hour]:[minute]:[second]")?;
     add_entry(
         config.cfg_map_mut(),
         VergenKey::CommitTime,
-        Some(now.format("%H:%M:%S").to_string()),
+        Some(now.format(&format)?),
     );
+    Ok(())
 }
 
 #[cfg(feature = "git")]
-fn add_timestamp_entry<T>(config: &mut Config, now: &DateTime<T>)
-where
-    T: TimeZone,
-    T::Offset: std::fmt::Display,
-{
+fn add_timestamp_entry(config: &mut Config, now: &OffsetDateTime) -> Result<()> {
     add_entry(
         config.cfg_map_mut(),
         VergenKey::CommitTimestamp,
-        Some(now.to_rfc3339()),
+        Some(now.format(&Rfc3339)?),
     );
+    Ok(())
 }
 
 #[cfg(feature = "git")]
